%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%% Demonstration Tool for RTHS %%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%  Gaby Ou, 05/14/2013 %%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%IISL, Purdue University%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% for general description, see 'read me.txt'
% for detail instruction see 'A Real Time Hybrid Simulation demo document.pdf'

clc
clear all
close all
warning off

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%       Entire Building Information         %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
M  	 = 155.6;					% mass per floor [N/(m/sec2)]
K       = 1.004922e+05 ;			    % N/m
Zeta  = 0.02;
C=2*Zeta*sqrt(K*M);
wn_T=sqrt(K/M)/(2*pi());
wd_T=wn_T*sqrt(1-Zeta^2);

disp(['Entire Structure Natural Frequency is ' num2str(wd_T) ' Hz'])

AA_T=[0 1; -K/M -C/M];
BB_T=[0; -1];
CC_T=[1 0; 0 1; -K/M -C/M];
DD_T=[0; 0; -1];
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%            Patitioning of RTHS            %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
R_ME=0.15; %ratio of floor mass in experimental substructure
% not suggested over 0.35
R_KE=0.15; %ratio of floor stiffness in experimental substructure
Zeta_E=0.0045; %damping ratio of first story

% CHECK STABILITY OF Partition
if (R_ME > 0.35)
    disp(' ')
    disp('Unacceptable Mass Partition !')
end

ME=R_ME*M;
KE=R_KE*K;
CE=2*Zeta_E*sqrt(KE*ME);
wn_E=sqrt(KE/ME)/(2*pi());
wd_E=wn_E*sqrt(1-Zeta_E^2);

disp(['Experimental substructure natural Frequency is ' num2str(wd_E) ' Hz'])

MN=M-ME;
KN=K-KE;
CN=C-CE;

AA_N=[0 1; -KN/MN -CN/MN];
BB_N=[0 0; -M/MN -1/MN];
CC_N=[1 0; 0 1; -KN/MN -CN/MN];
DD_N=[0 0; 0 0; -M/MN -1/MN];

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%      Actuator Dynamics and Control        %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
C_sw = 4;             % actuator compensation switch choose from 1-8
load (['Level_' num2str(C_sw) '_comp.mat']);
load ACT_DYN;          % actuator dyanmcis

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%      General Simulation Parameter          %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
dt_rths = 1/1024;
eq_intensity = 1;   % EQ Intensity
E_sw = 1;             % Earthquake switch 1: el centro 2: kobe 3: morgan
tend=80;              % Earthquake Ending Time
sim ('RTHS_DM')

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%     Data Analysis: RTHS vs Entire Structure     %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%figure 1: plot displcement response from FULL RTHS, IDEAL RTHS and Entire sutructure
scrsz = get(0,'ScreenSize');
figure('Position',[5 scrsz(4)*(0.53) scrsz(3)*(1/3-1/100) scrsz(4)*(1/2-1/8)])
subplot(211)
plot(t,RTHS_Resp_FULL(:,1),t,RTHS_Resp_IDL(:,1),t,Total_Resp(:,1),':')
ylabel('Displacement(m)')
legend('RTHS FULL Case','RTHS Ideal Case','Simulation',4)
% title('Structrual displacement comparison')
subplot(212)
plot(t,RTHS_Resp_FULL(:,1),t,RTHS_Resp_IDL(:,1),t,Total_Resp(:,1),':','linewidth',2)
ylabel('Displacement(m)')
xlabel('time(sec)')
xlim([5 15])

%figure 2: plot velocity response from FULL RTHS, IDEAL RTHS and Entire sutructure
figure('Position',[5+scrsz(3)/3 scrsz(4)*(0.53) scrsz(3)*(1/3-1/100) scrsz(4)*(1/2-1/8)])
subplot(211)
plot(t,RTHS_Resp_FULL(:,2),t,RTHS_Resp_IDL(:,2),t,Total_Resp(:,2),':')
ylabel('Velocity(m/s)')
legend('RTHS Full Case','RTHS Ideal Case','Simulation',4)
% title('Structrual velocity comparison')
subplot(212)
plot(t,RTHS_Resp_FULL(:,2),t,RTHS_Resp_IDL(:,2),t,Total_Resp(:,2),':','linewidth',2)
ylabel('Velocity(m/s)')
xlabel('time(sec)')
xlim([5 15])

%figure 3: plot velocity response from FULL RTHS, IDEAL RTHS and Entire sutructure
figure('Position',[5+scrsz(3)*(2/3) scrsz(4)*(0.53) scrsz(3)*(1/3-1/100) scrsz(4)*(1/2-1/8)])
subplot(211)
plot(t,RTHS_Resp_FULL(:,3),t,RTHS_Resp_IDL(:,3),t,Total_Resp(:,3),':')
ylabel('Acceleration(m/s^2)')
legend('RTHS Full Case','RTHS Ideal Case','Simulation',4)
% title('Structrual acceleration comparison')
subplot(212)
plot(t,RTHS_Resp_FULL(:,3),t,RTHS_Resp_IDL(:,3),t,Total_Resp(:,3),':','linewidth',2)
ylabel('Acceleration(m/s^2)')
xlabel('time(sec)')
xlim([5 15])

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%     Data Analysis: FULL RTHS vs IDEAL RTHS      %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%figure 4: plot actuator control performance
figure('Position',[5 scrsz(4)*(1/20) scrsz(3)*(1/3-1/100) scrsz(4)*(1/2-1/8)])
subplot(211)
plot(t,DM,t,DD)
ylabel('displacement(m)')
legend('Actuator Displacement','Command Displacement',4)
% title('Actuator Displacement Control Performance')
subplot(212)
plot(t,DM,t,DD,':','linewidth',2)
ylabel('Displacement(mm)')
xlabel('time(sec)')
xlim([5 10])

%figure 5: plot FULL RTHS Restoring force and IDEAL RTHS Restoring force
figure('Position',[5+scrsz(3)*(1/3) scrsz(4)*(1/20) scrsz(3)*(1/3-1/100) scrsz(4)*(1/2-1/8)])
subplot(211)
plot(t,RTHS_Force_FULL,t,RTHS_Force_IDL)
ylabel('Restoring Force(N)')
legend('Full case RTHS restoring force','IDEAL case RTHS restoring force',4)
% title('Feedback Restoring Force between Full RTHS and Ideal RTHS')
subplot(212)
plot(t,RTHS_Force_FULL,t,RTHS_Force_IDL,':','linewidth',2)
ylabel('Restoring Force(N)')
xlabel('time(sec)')
xlim([5 10])

